import 'package:dart_redis_connector/dart_redis_connector.dart';
import 'package:spec/spec.dart';

void main() {
  group('RedisOptions', () {
    group('RedisOptions.fromUrl', () {
      test('should parse redis or rediss schemes', () {
        expect(RedisOptions.fromUri(Uri.parse('redis://localhost:6379')).tls)
            .toBe(false);
        expect(RedisOptions.fromUri(Uri.parse('rediss://localhost:6379')).tls)
            .toBe(true);
      });

      test('should throw if scheme is not redis or rediss', () {
        expect(() => RedisOptions.fromUri(Uri.parse('http://localhost:6379')))
            .throws
            .isArgumentError();
      });

      test('should default to localhost if no host in uri', () {
        expect(RedisOptions.fromUri(Uri.parse('redis://')).host)
            .toEqual('localhost');
      });

      test('should default to 6379 if no port in uri', () {
        expect(RedisOptions.fromUri(Uri.parse('redis://localhost')).port)
            .toEqual(6379);
      });

      test('should default to 0 if no database in uri', () {
        expect(
          RedisOptions.fromUri(Uri.parse('redis://localhost:6379')).database,
        ).toEqual(0);
      });

      test('should read database from first path segment', () {
        expect(
          RedisOptions.fromUri(Uri.parse('redis://localhost:6379/2')).database,
        ).toEqual(2);
      });

      test('should read database from query parameter', () {
        expect(
          RedisOptions.fromUri(Uri.parse('redis://localhost:6379?db=3'))
              .database,
        ).toEqual(3);
      });

      test('should read username from userinfo', () {
        expect(
          RedisOptions.fromUri(
            Uri.parse('redis://user:password@localhost:6379'),
          ).username,
        ).toEqual('user');
      });

      test('should read username from query parameter', () {
        expect(
          RedisOptions.fromUri(
            Uri.parse('redis://localhost:6379?username=user'),
          ).username,
        ).toEqual('user');
      });

      test('should read password from userinfo', () {
        expect(
          RedisOptions.fromUri(
            Uri.parse('redis://user:password@localhost:6379'),
          ).password,
        ).toEqual('password');
      });

      test('should read password from query parameter', () {
        expect(
          RedisOptions.fromUri(
            Uri.parse('redis://localhost:6379?password=password'),
          ).password,
        ).toEqual('password');
      });

      test('should return null if password is empty', () {
        expect(
          RedisOptions.fromUri(Uri.parse('redis://user:@localhost:6379'))
              .password,
        ).isNull();
      });
    });
  });
}
